# ISC License
#
# Copyright 2019 FL Fintech E GmbH
#
# Permission to use, copy, modify, and/or distribute this software for any purpose with or without fee is hereby granted, provided that the above copyright notice and this permission notice appear in all copies.
#
# THE SOFTWARE IS PROVIDED "AS IS" AND THE AUTHOR DISCLAIMS ALL WARRANTIES WITH REGARD TO THIS SOFTWARE INCLUDING ALL IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS. IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY SPECIAL, DIRECT, INDIRECT, OR CONSEQUENTIAL DAMAGES OR ANY DAMAGES WHATSOEVER RESULTING FROM LOSS OF USE, DATA OR PROFITS, WHETHER IN AN ACTION OF CONTRACT, NEGLIGENCE OR OTHER TORTIOUS ACTION, ARISING OUT OF OR IN CONNECTION WITH THE USE OR PERFORMANCE OF THIS SOFTWARE.

from click.testing import CliRunner # pylint: disable=E0401

from k8t.cli import root


def test_single_cluster():
    runner = CliRunner()

    result = runner.invoke(root, ['get', 'clusters', 'examples/single-cluster'])

    assert result.exit_code == 0
    assert result.output == ''

    result = runner.invoke(root, ['get', 'environments', 'examples/single-cluster'])

    assert result.exit_code == 0
    assert 'production' in result.output

    result = runner.invoke(root, ['validate', 'examples/single-cluster'])

    assert result.exit_code == 0
    assert 'hello-world-deployment.yaml.j2: ✔' in result.output
    assert 'hello-world-secret.yaml.j2: ✔' in result.output
    assert 'hello-world-service.yaml.j2: ✔' in result.output
